@@ -3,8 +3,8 @@
 import copy
 
 
-def clone(obj, empty=False):
-    d = copy.deepcopy(obj)
+def clone(obj, empty=False, memo=None):
+    d = copy.deepcopy(obj, memo)
     if empty:
         d.clear()
     return d
