@@ -81,6 +81,16 @@ class IODict(BaseDict):
         kwargs['columns_row'] = columns_row
         return cls(s, format='csv', **kwargs)
 
+    @classmethod
+    def from_ini(cls, s, **kwargs):
+        """
+        Load and decode INI data from url, filepath or data-string.
+        Decoder specific options can be passed using kwargs:
+        https://docs.python.org/3/library/configparser.html
+        Return a new dict instance. A ValueError is raised in case of failure.
+        """
+        return cls(s, format='ini', **kwargs)
+
     @classmethod
     def from_json(cls, s, **kwargs):
         """
@@ -159,11 +169,11 @@ class IODict(BaseDict):
         """
         kwargs['subformat'] = subformat
         kwargs['encoding'] = encoding
-        return self._encode(self, 'base64', **kwargs)
+        return self._encode(self.dict(), 'base64', **kwargs)
 
     def to_csv(self, key='values', columns=None, columns_row=True, **kwargs):
         """
-        Encode the current dict instance in CSV format.
+        Encode a list of dicts in the current dict instance in CSV format.
         Encoder specific options can be passed using kwargs:
         https://docs.python.org/3/library/csv.html
         Return the encoded string and optionally save it at 'filepath'.
@@ -171,7 +181,17 @@ class IODict(BaseDict):
         """
         kwargs['columns'] = columns
         kwargs['columns_row'] = columns_row
-        return self._encode(self[key], 'csv', **kwargs)
+        return self._encode(self.dict()[key], 'csv', **kwargs)
+
+    def to_ini(self, **kwargs):
+        """
+        Encode the current dict instance in INI format.
+        Encoder specific options can be passed using kwargs:
+        https://docs.python.org/3/library/configparser.html
+        Return the encoded string and optionally save it at 'filepath'.
+        A ValueError is raised in case of failure.
+        """
+        return self._encode(self.dict(), 'ini', **kwargs)
 
     def to_json(self, **kwargs):
         """
@@ -181,7 +201,7 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        return self._encode(self, 'json', **kwargs)
+        return self._encode(self.dict(), 'json', **kwargs)
 
     def to_pickle(self, **kwargs):
         """
@@ -192,7 +212,7 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        return self._encode(self, 'pickle', **kwargs)
+        return self._encode(self.dict(), 'pickle', **kwargs)
 
     def to_plist(self, **kwargs):
         """
@@ -202,7 +222,7 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        return self._encode(self, 'plist', **kwargs)
+        return self._encode(self.dict(), 'plist', **kwargs)
 
     def to_query_string(self, **kwargs):
         """
@@ -210,7 +230,7 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        return self._encode(self, 'query_string', **kwargs)
+        return self._encode(self.dict(), 'query_string', **kwargs)
 
     def to_toml(self, **kwargs):
         """
@@ -220,7 +240,7 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        return self._encode(self, 'toml', **kwargs)
+        return self._encode(self.dict(), 'toml', **kwargs)
 
     def to_xml(self, **kwargs):
         """
@@ -230,7 +250,7 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        return self._encode(self, 'xml', **kwargs)
+        return self._encode(self.dict(), 'xml', **kwargs)
 
     def to_yaml(self, **kwargs):
         """
@@ -240,4 +260,4 @@ class IODict(BaseDict):
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        return self._encode(self, 'yaml', **kwargs)
+        return self._encode(self.dict(), 'yaml', **kwargs)
